Models
======

.. currentmodule:: graspologic.models

Erdos-Reyni models
------------------

.. autoclass:: EREstimator

.. autoclass:: DCEREstimator

Stochastic block models
-----------------------

.. autoclass:: SBMEstimator

.. autoclass:: DCSBMEstimator

Latent position models
----------------------

.. autoclass:: RDPGEstimator
